'use strict';

var htmlMinifier = require('html-minifier');
var sass = require('sass');
var esbuild = require('esbuild');

function _interopDefaultLegacy (e) { return e && typeof e === 'object' && 'default' in e ? e : { 'default': e }; }

var sass__default = /*#__PURE__*/_interopDefaultLegacy(sass);

const htmlMinify = (html) => htmlMinifier.minify(html, {
    collapseBooleanAttributes: true,
    collapseInlineTagWhitespace: true,
    collapseWhitespace: true,
    decodeEntities: true,
    removeComments: true,
    sortAttributes: true,
    sortClassName: true,
    minifyCSS: (text) => sass__default["default"].renderSync({ data: text, outputStyle: "compressed" }).css.toString(),
    minifyJS: (text) => esbuild.buildSync({
        stdin: { contents: text, loader: "ts", resolveDir: process.cwd() },
        bundle: true,
        minify: true,
        write: false,
    }).outputFiles[0].text,
});
var index = ({ types: t }, { separator = "\0" }) => {
    return {
        name: "html-template",
        visitor: {
            TaggedTemplateExpression: {
                exit(path) {
                    const { tag, quasi: { quasis, expressions }, } = path.node;
                    if (tag.type === "Identifier" && tag.name === "html") {
                        path.get("quasi").replaceWith(t.templateLiteral(htmlMinify(quasis.map((quasi) => quasi.value.cooked).join(separator))
                            .split(separator)
                            .map((cooked) => t.templateElement({ raw: cooked })), expressions));
                    }
                },
            },
        },
    };
};

module.exports = index;
