import { minify } from 'html-minifier';
import sass from 'sass';
import { buildSync } from 'esbuild';

const htmlMinify = (html) => minify(html, {
    collapseBooleanAttributes: true,
    collapseInlineTagWhitespace: true,
    collapseWhitespace: true,
    decodeEntities: true,
    removeComments: true,
    sortAttributes: true,
    sortClassName: true,
    minifyCSS: (text) => sass.renderSync({ data: text, outputStyle: "compressed" }).css.toString(),
    minifyJS: (text) => buildSync({
        stdin: { contents: text, loader: "ts", resolveDir: process.cwd() },
        bundle: true,
        minify: true,
        write: false,
    }).outputFiles[0].text,
});
var index = ({ types: t }, { separator = "\0" }) => {
    return {
        name: "html-template",
        visitor: {
            TaggedTemplateExpression: {
                exit(path) {
                    const { tag, quasi: { quasis, expressions }, } = path.node;
                    if (tag.type === "Identifier" && tag.name === "html") {
                        path.get("quasi").replaceWith(t.templateLiteral(htmlMinify(quasis.map((quasi) => quasi.value.cooked).join(separator))
                            .split(separator)
                            .map((cooked) => t.templateElement({ raw: cooked })), expressions));
                    }
                },
            },
        },
    };
};

export { index as default };
